summaryrefslogtreecommitdiff
path: root/applets/clock/clock-map.c
diff options
context:
space:
mode:
Diffstat (limited to 'applets/clock/clock-map.c')
-rw-r--r--applets/clock/clock-map.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/applets/clock/clock-map.c b/applets/clock/clock-map.c
index 0c371ca1..1aa2202e 100644
--- a/applets/clock/clock-map.c
+++ b/applets/clock/clock-map.c
@@ -100,7 +100,7 @@ clock_map_class_init (ClockMapClass *this_class)
* The map widget emits this signal when it needs to know which
* locations to display.
*
* Returns: the handler should return a (GList *) of (ClockLocation *).
* The map widget will not modify this list, so the caller should keep
* it alive.
*/
@@ -429,7 +429,7 @@ static void
clock_map_place_locations (ClockMap *this)
{
ClockMapPrivate *priv = clock_map_get_instance_private (this);
- GList *locs;
+ GSList *locs;
ClockLocation *loc;
if (priv->location_map_pixbuf) {
@@ -100,7 +100,7 @@ clock_map_class_init (ClockMapClass *this_class)
* locations to display.
*
- * Returns: the handler should return a (GList *) of (ClockLocation *).
+ * Returns: the handler should return a (GSList *) of (ClockLocation *).
* The map widget will not modify this list, so the caller should keep
* it alive.